@@ -153,9 +153,9 @@ class DataClient(object):
                 response = decode_message(response.content)
                 self.manage_exceptions(response)  # this raises on errors
                 return response
-            except TimeoutError as err:
+            except (TimeoutError, DatafeedError) as err:
                 # --- send clear-cache request to the router (the cached
-                #     value is a timout error) and try again
+                #     value is the error information) and try again
                 requests.delete(base_url, params=request)
                 if ntries < fail_after:
                     ntries += 1
