@@ -236,9 +236,9 @@ class DataServer(tornado.tcpserver.TCPServer):
                 resp = await self.thrd_async(
                     bdp_request, clt, self.blp_timeout, request)
             else:
-                # --- for BDH requests allow for longer timeout
+                # --- for BDH requests allow for much longer timeout
                 resp = await self.thrd_async(
-                    bdh_request, 2*self.blp_timeout, request)
+                    bdh_request, 5*self.blp_timeout, request)
         except TimeoutError:
             err_msg = \
                 f"bloomberg request timed out after {self.blp_timeout!s} ms"
@@ -246,10 +246,9 @@ class DataServer(tornado.tcpserver.TCPServer):
                 "type": "TimeoutError",
                 "payload": err_msg
             }
-            # # --- try re-initializing clients
-            # for clt in self.bdp_clients:
-            #     clt.stop()
-            #     clt.initialize_session_and_service()
+            # --- try re-initializing client
+            clt.stop()
+            clt.initialize_session_and_service()
         except DatafeedFatal as err:
             # --- unrecoverable bloomberg error: don't send a reply so that
             #     the datafeed router knows this server is currently unable
